//Grass texture
//#declare PigGrass = pigment{srgb<0.45, 0.6, 0.25>} //{srgb <0.4, 1, 0.1>}
#declare TGrass = texture{pigment{ color srgb < 94 / 255, 135 / 255, 63 / 255 > } }

#declare RandGen = seed(79230);
#declare RandEp = seed(79000);//Seed for space grass blades
#declare RandColor = seed(1234);
#declare RandRotate = seed(5678);

#declare GBDk = < 63 / 255, 82 / 255, 12 / 255 >; //Grass blade Dark color
#declare GBLg = < 109 / 255, 130 / 255, 67 / 255 >; //Grass blade light color
#declare GCoefDir = < GBLg.x - GBDk.x, GBLg.y - GBDk.y , GBLg.z - GBDk.z>; //Grass col coef dir
 

//Place trees in the background line
//Trees in the background parameters
#declare EucalyptusCount = 81;
#declare Delta = 4;
#declare VectPlace = < 5 / Delta, 0, 6 / Delta >;
#declare StartingPoint = < -20, -0.25, 0 > - VectPlace*12;

#declare MapleCount = 82;

#macro PlaceBackgroundMaples(OffsetVector)
	#local MaplePos = StartingPoint + /*<-8, 0 , 8>*/ + OffsetVector;
	#local TreesCount = 0;
	#while( TreesCount < MapleCount )
		#if( !( MaplePos.x >= -20 & MaplePos.x <= -8 ) )
			object{MapleB2 rotate (360*rand(RandGen))*y scale <5, 5 + 4 * rand(RandGen) , 5> translate MaplePos} 
		#end
		#local TreesCount = TreesCount + 1;
		#local MaplePos = MaplePos + VectPlace;
	#end
#end

#macro PlaceDistantMaples(TreesNumber, OffsetVector, SpacingVector)
	#local MaplePos = StartingPoint + OffsetVector;
	#local TreesCount = 0;
	
	#while( TreesCount < TreesNumber )
		#if( !( MaplePos.x >= -20 & MaplePos.x <= -8 ) ) 
			object{MapleB2 rotate (360*rand(RandGen))*y scale <8, 8 + 4*rand(RandGen), 8> translate MaplePos}
		#end
		#local TreesCount = TreesCount + 1;
		#local MaplePos = MaplePos + SpacingVector;
	#end
#end

//Place grass blade
	#declare Asw = < -32.5, 0, -15 >; //Point triangulation south-west
	#declare Bn = < 44, 0, 75 >; //Point triangulation north
	#declare Cse = < 26, 0, -35 >; //Point triangulation south-east
	#declare CA = Asw - Cse;
	#declare AB = Bn - Asw;
	#declare BC = Cse - Bn;
	#declare CA_Perp = vrotate( CA, < 0, 90, 0 > );
	#declare AB_Perp = vrotate( AB, < 0, 90, 0 > );
	#declare BC_Perp = vrotate( BC, < 0, 90, 0 > );
	
	//GrassSquare
	#declare TopLeft = <-32.5, 0, 75>;
	#declare BottomRight = <42.5, 0, -35>;//Good value <42.5, 0, -35>
	#declare QuickBottomRight = <30, 0, -35>;
	#declare QuickTopLeft= <0, 0, 0>;
	
	#declare BladeDensity = 12; //2 * Per 1 unit square
	
#declare AllGround = 
union{
	object{ ConcreteGround } 
	object{ EarthGround}
}

#declare GrassBladeFinish = finish{ diffuse 0.8 specular 0.35 roughness 0.01 }

#macro PlaceGrass()
	#debug "Starting to place grass on the ground\n"
	#local GrassBladeCount = 0;
	#local Norm = <0, 0, 0>;
	
    #for(XCount, TopLeft.x, BottomRight.x )
		#for(ZCount, BottomRight.z, TopLeft.z )
			#for(InXBetween, -BladeDensity, BladeDensity - 1)
				#for(InZBetween, -BladeDensity, BladeDensity - 1)
					#local Start = < XCount + (InXBetween + rand(RandGen)) / (BladeDensity * 2), 1000, ZCount + (InZBetween + rand(RandGen)) / (BladeDensity * 2) >;
					#declare PosBlade = trace( AllGround, Start, -y, Norm );
					#if( PosBlade.y != 0.001 & vdot(CA_Perp, PosBlade - Cse) > 0 & vdot(AB_Perp, PosBlade - Asw) > 0 & vdot(BC_Perp, PosBlade - Bn) > 0 & rand(RandEp) > 0.5 )
						cylinder{0, <0, (0.025 + rand(RandGen)/25), 0>, 0.0085 scale <1,1,0.35> rotate <rand(RandRotate)*20-10 ,(360 * rand(RandGen) ), rand(RandRotate)*20-10> translate PosBlade 
							texture{pigment{color srgb<GCoefDir.x*rand(RandColor)+GBLg.x, GCoefDir.y*rand(RandColor)+GBLg.y, GCoefDir.z*rand(RandColor)+GBLg.z>} finish{ GrassBladeFinish }} }
						#local GrassBladeCount = GrassBladeCount + 1;
					#end
				#end
			#end
		#end
	#end
	#debug concat("Placed ", str(GrassBladeCount,0,0), " grass blades\n")
#end


